@@ -83,7 +83,7 @@ class GameConfig:
     def make_data_dir(self):
         data_env = os.getenv("DATA_DIR") or self.app_dir
 
-        data_dir_path = os.path.join(self.data_dir, "fantomatic_data")
+        data_dir_path = os.path.join(data_env, "fantomatic_data")
         if not os.path.isdir(data_dir_path):
             os.mkdir(data_dir_path)
         return data_dir_path
